@@ -17,8 +17,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import sys
-
 from oslo_config import cfg
 from oslo_log import log as logging
 
@@ -27,7 +25,6 @@ from os_vif.internal.ip.api import ip as ip_lib
 from os_vif import objects
 from os_vif import plugin
 
-
 from vif_plug_ovs import constants
 from vif_plug_ovs import exception
 from vif_plug_ovs import linux_net
@@ -181,9 +178,6 @@ class OvsPlugin(plugin.PluginBase):
     def supports_tc_qdisc(self, vif) -> bool:
         if self._get_vif_datapath_type(vif) != constants.OVS_DATAPATH_SYSTEM:
             return False
-        if sys.platform == constants.PLATFORM_WIN32:
-            return False
-
         return True
 
     def _isolate_vif(self, vif_name, bridge):
@@ -208,8 +202,12 @@ class OvsPlugin(plugin.PluginBase):
         # bound the interface in the vif binding details so isolation
         # can be enabled automatically in the future.
         bridge = kwargs.pop('bridge', vif.network.bridge)
-        if self._isolate_vif(vif_name, bridge):
+        # See bug #2069543.
+        if (self._isolate_vif(vif_name, bridge) and
+                not self._is_trunk_bridge(bridge)):
             kwargs['tag'] = constants.DEAD_VLAN
+            kwargs['vlan_mode'] = 'trunk'
+            kwargs['trunks'] = constants.DEAD_VLAN
         qos_type = self._get_qos_type(vif)
         if qos_type is not None:
             # NOTE(sean-k-mooney): If the port is not already created
@@ -283,14 +281,6 @@ class OvsPlugin(plugin.PluginBase):
             linux_net.update_veth_pair(v1_name, v2_name, mtu)
             self._update_vif_port(vif, v2_name)
 
-    def _plug_vif_windows(self, vif, instance_info):
-        """Create a per-VIF OVS port."""
-
-        if not ip_lib.exists(vif.id):
-            self.ovsdb.ensure_ovs_bridge(vif.network.bridge,
-                                         self._get_vif_datapath_type(vif))
-            self._create_vif_port(vif, vif.id, instance_info)
-
     def _plug_port_bridge(self, vif, instance_info):
         """Create a per-VIF OVS bridge and patch pair."""
 
@@ -317,8 +307,8 @@ class OvsPlugin(plugin.PluginBase):
         instance_id = instance_info.uuid
         LOG.debug(
             'creating patch port pair \n'
-            f'{port_bridge_name}:({port_bridge_patch}) -> '
-            f'{int_bridge_name}:({int_bridge_patch})'
+            f'{port_bridge_name}: ({port_bridge_patch}) -> '
+            f'{int_bridge_name}: ({int_bridge_patch})'
         )
         self.ovsdb.create_patch_port_pair(
             port_bridge_name, port_bridge_patch, int_bridge_name,
@@ -381,15 +371,7 @@ class OvsPlugin(plugin.PluginBase):
             raise exception.WrongPortProfile(
                 profile=vif.port_profile.__class__.__name__)
 
-        if sys.platform == constants.PLATFORM_WIN32:
-            if type(vif) not in (
-                objects.vif.VIFOpenVSwitch, objects.vif.VIFBridge
-            ):
-                raise osv_exception.PlugException(
-                    vif=vif, err="This vif type is not supported on Windows")
-
-            self._plug_vif_windows(vif, instance_info)
-        elif isinstance(vif, objects.vif.VIFOpenVSwitch):
+        if isinstance(vif, objects.vif.VIFOpenVSwitch):
             if self.config.per_port_bridge:
                 self._plug_port_bridge(vif, instance_info)
             else:
@@ -443,12 +425,6 @@ class OvsPlugin(plugin.PluginBase):
             qos_type = self.config.default_qos_type
         return qos_type
 
-    def _unplug_vif_windows(self, vif, instance_info):
-        """Remove port from OVS."""
-        self.ovsdb.delete_ovs_vif_port(vif.network.bridge, vif.id,
-                                       delete_netdev=False)
-        self._delete_bridge_if_trunk(vif)
-
     def _unplug_port_bridge(self, vif, instance_info):
         """Create a per-VIF OVS bridge and patch pair."""
         # NOTE(sean-k-mooney): the port name prefix should not be
@@ -508,14 +484,7 @@ class OvsPlugin(plugin.PluginBase):
                           objects.vif.VIFPortProfileOpenVSwitch):
             raise exception.WrongPortProfile(
                 profile=vif.port_profile.__class__.__name__)
-        if sys.platform == constants.PLATFORM_WIN32:
-            if type(vif) not in (
-                objects.vif.VIFOpenVSwitch, objects.vif.VIFBridge
-            ):
-                raise osv_exception.UnplugException(
-                    vif=vif, err="This vif type is not supported on windows.")
-            self._unplug_vif_windows(vif, instance_info)
-        elif isinstance(vif, objects.vif.VIFOpenVSwitch):
+        if isinstance(vif, objects.vif.VIFOpenVSwitch):
             if self.config.per_port_bridge:
                 self._unplug_port_bridge(vif, instance_info)
             else:
